<?php

namespace App\Command;

use App\Repository\UserRepository;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Component\Console\Attribute\AsCommand;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

#[AsCommand(
    name: 'rekall:set-default-user-locales',
    description: 'Set default user locales for user that did not set it',
    aliases: ['r:set-default-user-locale'],
    hidden: false
)]
class UpdateUserLocale extends Command
{
    protected static $defaultName = 'rekall:set-default-user-locales';

    public function __construct(
        private UserRepository $user_repository,
        private EntityManagerInterface $entity_manager
    ) {
        parent::__construct();
    }

    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $output->writeln('Setting locales for users that did not set it yet');

        $all_users = $this->user_repository->findAll();
        foreach ($all_users as $user) {
            if ($user->getLocale() === "") {
                $user->setLocale('en');
                $this->entity_manager->persist($user);
            }
        }
        $this->entity_manager->flush();

        $output->writeln('User locales successfully set to english');

        return Command::SUCCESS;
    }
}
